Please read the `documentation <https://yaml4rst.readthedocs.io/en/latest/>`_
and especially the `Design prinipials <https://yaml4rst.readthedocs.io/en/latest/design.html>`_ first before opening a pull request.
Thanks!
